@@ -9,6 +9,8 @@ __docformat__ = "restructuredtext en"
 
 import datetime
 
+from logilab.common.date import todate
+
 from logilab.mtconverter import xml_escape
 
 from cubicweb.utils import UStringIO
@@ -19,6 +21,7 @@ from cubicweb.view import AnyRsetView, EntityView, EntityAdapter
 from cubicweb.web import INTERNAL_FIELD_VALUE, stdmsgs, action
 from cubicweb.web.views import tableview, calendar, navigation, editcontroller
 
+from cubes.calendar.views import get_date_range_from_reqform
 
 class ActivitySummaryView(AnyRsetView):
     __regid__ = 'actsummary'
@@ -45,18 +48,24 @@ class ActivitySummaryView(AnyRsetView):
             self.w(u'</tr>')
         self.w(u'</table>')
 
-
 class ActivitySubmitView(EntityView):
-    __regid__ = 'activities-submit'
-    __select__ = empty_rset() | is_instance('Activity')
+    __regid__ = 'activities-list'
+    __select__ = is_instance('Resource')
 
-    def call(self, year=None, month=None, day=None):
-        year = year or self._cw.form.get('year')
-        month = month or self._cw.form.get('month')
-        day = day or self._cw.form.get('day')
-        self.wview('activitytable', self.cw_rset, 'null')
-        self._cw.user.view('euser-activities-submitform', w=self.w,
-                           year=year, month=month, day=day)
+    def cell_call(self, row, col):
+        entity = self.cw_rset.get_entity(row, col)
+        firstday, lastday = get_date_range_from_reqform(self._cw.form)
+        rql = 'Any A WHERE A is Activity, A done_by R, R eid %(r)s'
+        if lastday is None:
+            rql += ', A diem %(fd)s'
+        else:
+            rql += ', A diem >= %(fd)s, A diem <= %(ld)s'
+        rset = self._cw.execute(rql, {'r': entity.eid,
+                                      'fd': firstday, 'ld': lastday})
+        self.wview('activitytable', rset, 'null')
+        self.wview('activities-submitform',
+                   rset=self.cw_rset, row=row, col=col,
+                   initargs={'date': firstday})
 
 
 # XXX see generic definition for tablecontext view in gingouz.views
@@ -121,7 +130,7 @@ class ActivityCalendarItemView(calendar.CalendarItemView):
     def cell_call(self, row, col):
         activity = self.cw_rset.get_entity(row, col)
         self.w(u'<a href="%s">%s %s</a>' % (xml_escape(activity.absolute_url()),
-                                            xml_escape(activity.done_for[0].dc_long_title()),
+                                            xml_escape(activity.workorder.dc_long_title()),
                                             activity.duration))
 
 
@@ -145,7 +154,7 @@ class ValidateActivitiesAction(action.Action):
                 entity = req.entity_from_eid(eid, 'Activity')
                 entity.fire_transition('validate')
         msg = self._cw._('activities validated')
-        return self._cw.user_callback(validate_cb, (eids,), msg=msg)
+        return self._cw.user_callback(validate_cb, (eids,), msg)
 
 
 
