@@ -1,16 +1,18 @@
 from cubicweb.selectors import is_instance
 from cubicweb.web.views import autoform
-from cubicweb.web import INTERNAL_FIELD_VALUE, uicfg, formfields as ff
+from cubicweb.web import INTERNAL_FIELD_VALUE, uicfg, formfields as ff, formwidgets as fw
 from cubicweb.web.formwidgets import HiddenInput
 
 _afs = uicfg.autoform_section
-_afs.tag_attribute(('WorkOrder', 'progress_target'), 'main', 'hidden')
-_afs.tag_attribute(('WorkOrder', 'progress_todo'), 'main', 'hidden')
-_afs.tag_attribute(('WorkOrder', 'progress_done'), 'main', 'hidden')
-_afs.tag_subject_of(('Resource', 'use_calendar', '*'), 'main', 'inlined')
-
 _affk = uicfg.autoform_field_kwargs
 
+_afs.tag_subject_of(('Resource', 'use_calendar', '*'), 'main', 'inlined')
+_afs.tag_subject_of(('WorkOrder', 'uses_technology', '*'), 'main', 'attributes')
+_afs.tag_subject_of(('WorkOrder', 'uses_technology', '*'), 'muledit', 'attributes')
+# XXX should not be always hidden
+_affk.tag_subject_of(('Activity', 'done_by', '*'), {'widget': fw.HiddenInput})
+
+
 
 def tp_periods_choices(form, field, limit=None):
     #voc = self.object_relation_vocabulary(rtype, limit)
@@ -23,15 +25,6 @@ def tp_periods_choices(form, field, limit=None):
 _affk.tag_object_of(('*', 'periods', 'Timeperiod'),
                     {'choices': tp_periods_choices})
 
-def tp_day_type_choices(form, field, limit=None):
-    voc = field.__class__.choices(field, form, limit=limit)
-    if form._cw.form.get('vid') == 'holidays_form':
-        voc = [item for item in voc
-               if item[0] in form.conges_days]
-    return voc
-_affk.tag_subject_of(('Timeperiod', 'day_type', '*'),
-                     {'choices': tp_day_type_choices})
-
 
 
 def activity_done_by_choices(form, field, limit=None):
